==> gatling-recorder-bc-shaded-1.78.1-sources.jar: io/gatling/recorder/internal/bouncycastle/pqc/jcajce/provider/hqc/HQCKeyPairGeneratorSpi.java <==
package io.gatling.recorder.internal.bouncycastle.pqc.jcajce.provider.hqc;

import java.security.InvalidAlgorithmParameterException;
import java.security.KeyPair;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import java.util.HashMap;
import java.util.Map;

import io.gatling.recorder.internal.bouncycastle.crypto.AsymmetricCipherKeyPair;
import io.gatling.recorder.internal.bouncycastle.crypto.CryptoServicesRegistrar;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCKeyGenerationParameters;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCKeyPairGenerator;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCParameters;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCPrivateKeyParameters;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCPublicKeyParameters;
import io.gatling.recorder.internal.bouncycastle.pqc.jcajce.provider.util.SpecUtil;
import io.gatling.recorder.internal.bouncycastle.pqc.jcajce.spec.HQCParameterSpec;
import io.gatling.recorder.internal.bouncycastle.util.Strings;

public class HQCKeyPairGeneratorSpi
        extends java.security.KeyPairGenerator
{
    private static Map parameters = new HashMap();

    static
    {
        parameters.put("hqc-128", HQCParameters.hqc128);
        parameters.put("hqc-192", HQCParameters.hqc192);
        parameters.put("hqc-256", HQCParameters.hqc256);

        parameters.put(HQCParameterSpec.hqc128.getName(), HQCParameters.hqc128);
        parameters.put(HQCParameterSpec.hqc192.getName(), HQCParameters.hqc192);
        parameters.put(HQCParameterSpec.hqc256.getName(), HQCParameters.hqc256);
    }

    HQCKeyGenerationParameters param;
    HQCKeyPairGenerator engine = new HQCKeyPairGenerator();

    SecureRandom random = CryptoServicesRegistrar.getSecureRandom();
    boolean initialised = false;

    public HQCKeyPairGeneratorSpi()
    {
        super("HQC");
    }

    public void initialize(
            int strength,
            SecureRandom random)
    {
        throw new IllegalArgumentException("use AlgorithmParameterSpec");
    }

    public void initialize(
            AlgorithmParameterSpec params,
            SecureRandom random)
            throws InvalidAlgorithmParameterException
    {
        String name = getNameFromParams(params);

        if (name != null)
        {
            param = new HQCKeyGenerationParameters(random, (HQCParameters)parameters.get(name));

            engine.init(param);
            initialised = true;
        }
        else
        {
            throw new InvalidAlgorithmParameterException("invalid ParameterSpec: " + params);
        }
    }

    private static String getNameFromParams(AlgorithmParameterSpec paramSpec)
    {
        if (paramSpec instanceof HQCParameterSpec)
        {
            HQCParameterSpec hqcParams = (HQCParameterSpec)paramSpec;
            return hqcParams.getName();
        }
        else
        {
            return Strings.toLowerCase(SpecUtil.getNameFrom(paramSpec));
        }
    }

    public KeyPair generateKeyPair()
    {
        if (!initialised)
        {
            param = new HQCKeyGenerationParameters(random, HQCParameters.hqc128);

            engine.init(param);
            initialised = true;
        }

        AsymmetricCipherKeyPair pair = engine.generateKeyPair();
        HQCPublicKeyParameters pub = (HQCPublicKeyParameters)pair.getPublic();
        HQCPrivateKeyParameters priv = (HQCPrivateKeyParameters)pair.getPrivate();

        return new KeyPair(new BCHQCPublicKey(pub), new BCHQCPrivateKey(priv));
    }
}

==> gatling-recorder-bc-shaded-1.81.0-sources.jar: io/gatling/recorder/internal/bouncycastle/pqc/jcajce/provider/hqc/HQCKeyPairGeneratorSpi.java <==
package io.gatling.recorder.internal.bouncycastle.pqc.jcajce.provider.hqc;

import java.security.InvalidAlgorithmParameterException;
import java.security.KeyPair;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.security.spec.AlgorithmParameterSpec;
import java.util.HashMap;
import java.util.Map;

import io.gatling.recorder.internal.bouncycastle.crypto.AsymmetricCipherKeyPair;
import io.gatling.recorder.internal.bouncycastle.crypto.CryptoServicesRegistrar;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCKeyGenerationParameters;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCKeyPairGenerator;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCParameters;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCPrivateKeyParameters;
import io.gatling.recorder.internal.bouncycastle.pqc.crypto.hqc.HQCPublicKeyParameters;
import io.gatling.recorder.internal.bouncycastle.pqc.jcajce.provider.util.SpecUtil;
import io.gatling.recorder.internal.bouncycastle.pqc.jcajce.spec.HQCParameterSpec;
import io.gatling.recorder.internal.bouncycastle.util.Strings;

public class HQCKeyPairGeneratorSpi
    extends java.security.KeyPairGenerator
{
    private static Map parameters = new HashMap();

    static
    {
        parameters.put("hqc-128", HQCParameters.hqc128);
        parameters.put("hqc-192", HQCParameters.hqc192);
        parameters.put("hqc-256", HQCParameters.hqc256);

        parameters.put(HQCParameterSpec.hqc128.getName(), HQCParameters.hqc128);
        parameters.put(HQCParameterSpec.hqc192.getName(), HQCParameters.hqc192);
        parameters.put(HQCParameterSpec.hqc256.getName(), HQCParameters.hqc256);
    }

    HQCKeyGenerationParameters param;
    HQCKeyPairGenerator engine = new HQCKeyPairGenerator();

    SecureRandom random = CryptoServicesRegistrar.getSecureRandom();
    boolean initialised = false;

    public HQCKeyPairGeneratorSpi()
    {
        super("HQC");
    }

    protected HQCKeyPairGeneratorSpi(HQCParameterSpec paramSpec)
    {
        super(Strings.toUpperCase(paramSpec.getName()));
    }

    public void initialize(
        int strength,
        SecureRandom random)
    {
        throw new IllegalArgumentException("use AlgorithmParameterSpec");
    }

    public void initialize(
        AlgorithmParameterSpec params,
        SecureRandom random)
        throws InvalidAlgorithmParameterException
    {
        String name = getNameFromParams(params);

        if (name != null)
        {
            param = new HQCKeyGenerationParameters(random, (HQCParameters)parameters.get(name));

            engine.init(param);
            initialised = true;
        }
        else
        {
            throw new InvalidAlgorithmParameterException("invalid ParameterSpec: " + params);
        }
    }

    private static String getNameFromParams(AlgorithmParameterSpec paramSpec)
    {
        if (paramSpec instanceof HQCParameterSpec)
        {
            HQCParameterSpec hqcParams = (HQCParameterSpec)paramSpec;
            return hqcParams.getName();
        }
        else
        {
            return Strings.toLowerCase(SpecUtil.getNameFrom(paramSpec));
        }
    }

    public KeyPair generateKeyPair()
    {
        if (!initialised)
        {
            param = new HQCKeyGenerationParameters(random, HQCParameters.hqc128);

            engine.init(param);
            initialised = true;
        }

        AsymmetricCipherKeyPair pair = engine.generateKeyPair();
        HQCPublicKeyParameters pub = (HQCPublicKeyParameters)pair.getPublic();
        HQCPrivateKeyParameters priv = (HQCPrivateKeyParameters)pair.getPrivate();

        return new KeyPair(new BCHQCPublicKey(pub), new BCHQCPrivateKey(priv));
    }

    public static class HQC128
        extends HQCKeyPairGeneratorSpi
    {
        public HQC128()
            throws NoSuchAlgorithmException
        {
            super(HQCParameterSpec.hqc128);
        }
    }

    public static class HQC192
        extends HQCKeyPairGeneratorSpi
    {
        public HQC192()
            throws NoSuchAlgorithmException
        {
            super(HQCParameterSpec.hqc192);
        }
    }

    public static class HQC256
        extends HQCKeyPairGeneratorSpi
    {
        public HQC256()
            throws NoSuchAlgorithmException
        {
            super(HQCParameterSpec.hqc256);
        }
    }
}
